var page_pipewire =
[
    [ "Internals", "page_pipewire.html#autotoc_md5", null ],
    [ "Components", "page_pipewire.html#autotoc_md6", null ],
    [ "Backends", "page_pipewire.html#autotoc_md7", null ],
    [ "Design", "page_design.html", [
      [ "Protocol", "page_design.html#autotoc_md8", null ],
      [ "Extensibility", "page_design.html#autotoc_md9", null ]
    ] ],
    [ "Audio", "page_audio.html", [
      [ "Use Cases", "page_audio.html#autotoc_md94", [
        [ "Audio Devices Are Made Available As Processing Nodes/Ports", "page_audio.html#autotoc_md95", null ],
        [ "Audio Devices Can Be Plugged and Unplugged", "page_audio.html#autotoc_md96", null ],
        [ "Audio Port In Canonical Format", "page_audio.html#autotoc_md97", null ],
        [ "Applications Can Connect To Audio Devices", "page_audio.html#autotoc_md98", null ],
        [ "Default Audio Sink and Sources", "page_audio.html#autotoc_md99", null ],
        [ "Application Should Be Able To Move Between Sinks/Sources", "page_audio.html#autotoc_md100", null ],
        [ "Exclusive Access", "page_audio.html#autotoc_md101", null ]
      ] ],
      [ "Design", "page_audio.html#autotoc_md102", [
        [ "SPA", "page_audio.html#autotoc_md103", null ],
        [ "Audio Adapter", "page_audio.html#autotoc_md104", null ],
        [ "The Session Manager", "page_audio.html#autotoc_md105", null ]
      ] ],
      [ "Implementation", "page_audio.html#autotoc_md106", [
        [ "PipeWire Media Session (alsa-monitor)", "page_audio.html#autotoc_md107", null ]
      ] ]
    ] ],
    [ "Access Control", "page_access.html", [
      [ "Use Cases", "page_access.html#autotoc_md10", [
        [ "New Clients Need Their Permissions Configured", "page_access.html#autotoc_md11", null ],
        [ "Flatpaks Can't Modify Other Stream/Device Volumes", "page_access.html#autotoc_md12", null ],
        [ "Flatpaks Can't Move Other Streams To Different Devices", "page_access.html#autotoc_md13", null ],
        [ "Application Should Be Restricted In What They Can See", "page_access.html#autotoc_md14", null ],
        [ "\"Manager\" Applications Require Full Access", "page_access.html#autotoc_md15", null ]
      ] ],
      [ "Design", "page_access.html#autotoc_md16", [
        [ "The PipeWire Daemon", "page_access.html#autotoc_md17", null ],
        [ "The PipeWire Access Module", "page_access.html#autotoc_md18", null ],
        [ "The Session Manager", "page_access.html#autotoc_md19", null ]
      ] ]
    ] ],
    [ "Portal Access Control", "page_portal.html", [
      [ "Use Cases", "page_portal.html#autotoc_md33", [
        [ "New Portal Managed Clients Need Device Permissions Configured", "page_portal.html#autotoc_md34", null ],
        [ "New Devices Need To Be Made Visible To Portal Managed Clients", "page_portal.html#autotoc_md35", null ],
        [ "Permissions For A Device Need To Be Revoked", "page_portal.html#autotoc_md36", null ]
      ] ],
      [ "Design", "page_portal.html#autotoc_md37", [
        [ "The Portal", "page_portal.html#autotoc_md38", null ],
        [ "The PipeWire Portal Module", "page_portal.html#autotoc_md39", null ],
        [ "The Client", "page_portal.html#autotoc_md40", null ],
        [ "The Session Manager", "page_portal.html#autotoc_md41", null ]
      ] ]
    ] ],
    [ "MIDI Support", "page_midi.html", [
      [ "Use Cases", "page_midi.html#autotoc_md20", [
        [ "MIDI Devices Are Made Available As Processing Nodes/Ports", "page_midi.html#autotoc_md21", null ],
        [ "MIDI Devices Can Be Plugged and Unplugged", "page_midi.html#autotoc_md22", null ],
        [ "Applications Can Connect To MIDI Devices", "page_midi.html#autotoc_md23", null ],
        [ "Some MIDI Devices Are Sinks Or Sources For MIDI Data", "page_midi.html#autotoc_md24", null ],
        [ "Applications Should Auto-connect To MIDI Sinks Or Sources", "page_midi.html#autotoc_md25", null ]
      ] ],
      [ "Design", "page_midi.html#autotoc_md26", [
        [ "SPA", "page_midi.html#autotoc_md27", null ],
        [ "The PipeWire Daemon", "page_midi.html#autotoc_md28", null ],
        [ "The Session Manager", "page_midi.html#autotoc_md29", null ]
      ] ],
      [ "Implementation", "page_midi.html#autotoc_md30", [
        [ "PipeWire Media Session", "page_midi.html#autotoc_md31", null ],
        [ "JACK", "page_midi.html#autotoc_md32", null ]
      ] ]
    ] ],
    [ "Objects Design", "page_objects_design.html", [
      [ "The Media Graph", "page_objects_design.html#autotoc_md68", [
        [ "Node", "page_objects_design.html#autotoc_md69", null ],
        [ "Port", "page_objects_design.html#autotoc_md70", null ],
        [ "Link", "page_objects_design.html#autotoc_md71", null ]
      ] ],
      [ "The Session Management Graph", "page_objects_design.html#autotoc_md72", [
        [ "Endpoint", "page_objects_design.html#autotoc_md73", [
          [ "Target", "page_objects_design.html#autotoc_md74", null ]
        ] ],
        [ "Endpoint Stream", "page_objects_design.html#autotoc_md75", null ],
        [ "Endpoint Link", "page_objects_design.html#autotoc_md76", [
          [ "Constructing", "page_objects_design.html#autotoc_md77", null ]
        ] ]
      ] ],
      [ "Other Related Objects", "page_objects_design.html#autotoc_md78", [
        [ "Device", "page_objects_design.html#autotoc_md79", null ],
        [ "Session", "page_objects_design.html#autotoc_md80", [
          [ "Default Endpoints", "page_objects_design.html#autotoc_md81", null ],
          [ "Multiple Sessions", "page_objects_design.html#autotoc_md82", null ]
        ] ]
      ] ],
      [ "Mappings To Underlying Subsystem Objects", "page_objects_design.html#autotoc_md83", [
        [ "ALSA UCM", "page_objects_design.html#autotoc_md84", null ],
        [ "ALSA Fallback", "page_objects_design.html#autotoc_md85", null ],
        [ "V4L2", "page_objects_design.html#autotoc_md86", null ]
      ] ],
      [ "Relationship To Other API's", "page_objects_design.html#autotoc_md87", [
        [ "PulseAudio", "page_objects_design.html#autotoc_md88", [
          [ "Mapping PipeWire Objects For Access By PulseAudio Clients", "page_objects_design.html#autotoc_md89", null ],
          [ "Mapping PulseAudio Clients To PipeWire", "page_objects_design.html#autotoc_md90", null ]
        ] ],
        [ "Jack", "page_objects_design.html#autotoc_md91", [
          [ "Mapping PipeWire Objects For Access By JACK Clients", "page_objects_design.html#autotoc_md92", null ],
          [ "Mapping JACK Clients To PipeWire", "page_objects_design.html#autotoc_md93", null ]
        ] ]
      ] ]
    ] ],
    [ "PipeWire Library", "page_library.html", [
      [ "Principles", "page_library.html#autotoc_md45", null ],
      [ "Versioning", "page_library.html#autotoc_md46", null ],
      [ "Proxies and Resources", "page_library.html#autotoc_md47", null ],
      [ "Interfaces", "page_library.html#autotoc_md48", [
        [ "struct pw_loop", "page_library.html#autotoc_md49", null ],
        [ "struct pw_context", "page_library.html#autotoc_md50", null ],
        [ "struct pw_core", "page_library.html#autotoc_md51", null ],
        [ "struct pw_registry", "page_library.html#autotoc_md52", null ],
        [ "struct pw_module", "page_library.html#autotoc_md53", null ],
        [ "struct pw_factory", "page_library.html#autotoc_md54", null ],
        [ "struct pw_device", "page_library.html#autotoc_md55", null ],
        [ "struct pw_node", "page_library.html#autotoc_md56", null ],
        [ "struct pw_port", "page_library.html#autotoc_md57", null ],
        [ "struct pw_link", "page_library.html#autotoc_md58", null ]
      ] ],
      [ "High Level Helper Objects", "page_library.html#autotoc_md59", [
        [ "struct pw_filter", "page_library.html#autotoc_md60", null ],
        [ "struct pw_stream", "page_library.html#autotoc_md61", null ]
      ] ],
      [ "Security", "page_library.html#autotoc_md62", null ],
      [ "Implementation", "page_library.html#autotoc_md63", null ],
      [ "Error Reporting", "page_library.html#autotoc_md64", null ]
    ] ],
    [ "DMA-BUF Sharing", "page_dma_buf.html", [
      [ "Capability Negotiations", "page_dma_buf.html#autotoc_md290", [
        [ "pw_stream_connect", "page_dma_buf.html#autotoc_md291", null ],
        [ "param_changed Hook", "page_dma_buf.html#autotoc_md292", [
          [ "For Consumers", "page_dma_buf.html#autotoc_md293", null ],
          [ "For Producers", "page_dma_buf.html#autotoc_md294", null ]
        ] ],
        [ "add_buffer Hook", "page_dma_buf.html#autotoc_md295", null ],
        [ "on_event Hook", "page_dma_buf.html#autotoc_md296", null ],
        [ "Example Programs", "page_dma_buf.html#autotoc_md297", null ]
      ] ],
      [ "DMA-BUF Mapping Warning", "page_dma_buf.html#autotoc_md298", null ],
      [ "Size of DMA-BUFs", "page_dma_buf.html#autotoc_md299", null ],
      [ "v4l2", "page_dma_buf.html#autotoc_md300", null ]
    ] ],
    [ "Graph Scheduling", "page_scheduling.html", [
      [ "Nodes", "page_scheduling.html#autotoc_md108", null ],
      [ "Links", "page_scheduling.html#autotoc_md109", null ],
      [ "Drivers", "page_scheduling.html#autotoc_md110", [
        [ "Scheduling node A", "page_scheduling.html#autotoc_md111", null ],
        [ "Scheduling node B", "page_scheduling.html#autotoc_md112", null ],
        [ "Scheduling the driver", "page_scheduling.html#autotoc_md113", null ]
      ] ],
      [ "Remote nodes.", "page_scheduling.html#autotoc_md114", [
        [ "Remote driver nodes.", "page_scheduling.html#autotoc_md115", null ]
      ] ]
    ] ],
    [ "Native Protocol", "page_native_protocol.html", [
      [ "Message header", "page_native_protocol.html#autotoc_md116", null ],
      [ "Making a connection", "page_native_protocol.html#autotoc_md117", null ],
      [ "Core proxy/resource", "page_native_protocol.html#autotoc_md118", [
        [ "Core Methods (Id 0)", "page_native_protocol.html#autotoc_md119", [
          [ "Core::Hello (Opcode 1)", "page_native_protocol.html#autotoc_md120", null ],
          [ "Core::Sync (Opcode 2)", "page_native_protocol.html#autotoc_md121", null ],
          [ "Core::Pong (Opcode 3)", "page_native_protocol.html#autotoc_md122", null ],
          [ "Core::Error (Opcode 4)", "page_native_protocol.html#autotoc_md123", null ],
          [ "Core::GetRegistry (Opcode 5)", "page_native_protocol.html#autotoc_md124", null ],
          [ "Core::CreateObject (Opcode 6)", "page_native_protocol.html#autotoc_md125", null ],
          [ "Core::Destroy (Opcode 7)", "page_native_protocol.html#autotoc_md126", null ]
        ] ],
        [ "Core Events", "page_native_protocol.html#autotoc_md127", [
          [ "Core::Info (Opcode 0)", "page_native_protocol.html#autotoc_md128", null ],
          [ "Core::Done (Opcode 1)", "page_native_protocol.html#autotoc_md129", null ],
          [ "Core::Ping (Opcode 2)", "page_native_protocol.html#autotoc_md130", null ],
          [ "Core::Error (Opcode 3)", "page_native_protocol.html#autotoc_md131", null ],
          [ "Core::RemoveId (Opcode 4)", "page_native_protocol.html#autotoc_md132", null ],
          [ "Core::BoundId (Opcode 5)", "page_native_protocol.html#autotoc_md133", null ],
          [ "Core::AddMem (Opcode 6)", "page_native_protocol.html#autotoc_md134", null ],
          [ "Core::RemoveMem (Opcode 7)", "page_native_protocol.html#autotoc_md135", null ],
          [ "Core::BoundProps (Opcode 8)", "page_native_protocol.html#autotoc_md136", null ]
        ] ]
      ] ],
      [ "Registry proxy/resource", "page_native_protocol.html#autotoc_md137", [
        [ "Registry Methods", "page_native_protocol.html#autotoc_md138", [
          [ "Registry::Bind (Opcode 1)", "page_native_protocol.html#autotoc_md139", null ],
          [ "Registry::Destroy (Opcode 2)", "page_native_protocol.html#autotoc_md140", null ]
        ] ],
        [ "Registry Events", "page_native_protocol.html#autotoc_md141", [
          [ "Registry::Global (Opcode 0)", "page_native_protocol.html#autotoc_md142", null ],
          [ "Registry::GlobalRemove (Opcode 1)", "page_native_protocol.html#autotoc_md143", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Client", "page_native_protocol.html#autotoc_md144", [
        [ "Client Methods", "page_native_protocol.html#autotoc_md145", [
          [ "Client::Error (Opcode 1)", "page_native_protocol.html#autotoc_md146", null ],
          [ "Client::UpdateProperties (Opcode 2)", "page_native_protocol.html#autotoc_md147", null ],
          [ "Client::GetPermissions (Opcode 3)", "page_native_protocol.html#autotoc_md148", null ],
          [ "Client::UpdatePermissions (Opcode 4)", "page_native_protocol.html#autotoc_md149", null ]
        ] ],
        [ "Client Events", "page_native_protocol.html#autotoc_md150", [
          [ "Client::Info (Opcode 0)", "page_native_protocol.html#autotoc_md151", null ],
          [ "Client::Permissions (Opcode 1)", "page_native_protocol.html#autotoc_md152", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Device", "page_native_protocol.html#autotoc_md153", [
        [ "Device methods", "page_native_protocol.html#autotoc_md154", [
          [ "Device::SubscribeParams (Opcode 1)", "page_native_protocol.html#autotoc_md155", null ],
          [ "Device::EnumParams (Opcode 2)", "page_native_protocol.html#autotoc_md156", null ],
          [ "Device::SetParam (Opcode 3)", "page_native_protocol.html#autotoc_md157", null ]
        ] ],
        [ "Device events", "page_native_protocol.html#autotoc_md158", [
          [ "Device::Info (Opcode 0)", "page_native_protocol.html#autotoc_md159", null ],
          [ "Device::Param (Opcode 1)", "page_native_protocol.html#autotoc_md160", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Factory", "page_native_protocol.html#autotoc_md161", [
        [ "Factory methods", "page_native_protocol.html#autotoc_md162", null ],
        [ "Factory events", "page_native_protocol.html#autotoc_md163", [
          [ "Factory::Info (Opcode 0)", "page_native_protocol.html#autotoc_md164", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Link", "page_native_protocol.html#autotoc_md165", [
        [ "Link methods", "page_native_protocol.html#autotoc_md166", null ],
        [ "Link events", "page_native_protocol.html#autotoc_md167", [
          [ "Link::Info (Opcode 0)", "page_native_protocol.html#autotoc_md168", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Module", "page_native_protocol.html#autotoc_md169", [
        [ "Module methods", "page_native_protocol.html#autotoc_md170", null ],
        [ "Module events", "page_native_protocol.html#autotoc_md171", [
          [ "Module::Info (Opcode 0)", "page_native_protocol.html#autotoc_md172", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Node", "page_native_protocol.html#autotoc_md173", [
        [ "Node methods", "page_native_protocol.html#autotoc_md174", [
          [ "Node::SubscribeParams (Opcode 1)", "page_native_protocol.html#autotoc_md175", null ],
          [ "Node::EnumParams (Opcode 2)", "page_native_protocol.html#autotoc_md176", null ],
          [ "Node::SetParam (Opcode 3)", "page_native_protocol.html#autotoc_md177", null ],
          [ "Node::SendCommand (Opcode 4)", "page_native_protocol.html#autotoc_md178", null ]
        ] ],
        [ "Node events", "page_native_protocol.html#autotoc_md179", [
          [ "Node::Info (Opcode 0)", "page_native_protocol.html#autotoc_md180", null ],
          [ "Node::Param (Opcode 1)", "page_native_protocol.html#autotoc_md181", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Port", "page_native_protocol.html#autotoc_md182", [
        [ "Port methods", "page_native_protocol.html#autotoc_md183", [
          [ "Port::SubscribeParams (Opcode 1)", "page_native_protocol.html#autotoc_md184", null ],
          [ "Port::EnumParams (Opcode 2)", "page_native_protocol.html#autotoc_md185", null ]
        ] ],
        [ "Port events", "page_native_protocol.html#autotoc_md186", [
          [ "Port::Info (Opcode 0)", "page_native_protocol.html#autotoc_md187", null ],
          [ "Port::Param (Opcode 1)", "page_native_protocol.html#autotoc_md188", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:ClientNode", "page_native_protocol.html#autotoc_md189", [
        [ "ClientNode methods", "page_native_protocol.html#autotoc_md190", [
          [ "ClientNode::GetNode (Opcode 1)", "page_native_protocol.html#autotoc_md191", null ],
          [ "ClientNode::Update (Opcode 2)", "page_native_protocol.html#autotoc_md192", null ],
          [ "ClientNode::PortUpdate (Opcode 3)", "page_native_protocol.html#autotoc_md193", null ],
          [ "ClientNode::SetActive (Opcode 4)", "page_native_protocol.html#autotoc_md194", null ],
          [ "ClientNode::Event (Opcode 5)", "page_native_protocol.html#autotoc_md195", null ],
          [ "ClientNode::PortBuffers (Opcode 6)", "page_native_protocol.html#autotoc_md196", null ]
        ] ],
        [ "ClientNode events", "page_native_protocol.html#autotoc_md197", [
          [ "ClientNode::Transport (Opcode 0)", "page_native_protocol.html#autotoc_md198", null ],
          [ "ClientNode::SetParam (Opcode 1)", "page_native_protocol.html#autotoc_md199", null ],
          [ "ClientNode::SetIO (Opcode 2)", "page_native_protocol.html#autotoc_md200", null ],
          [ "ClientNode::Event (Opcode 3)", "page_native_protocol.html#autotoc_md201", null ],
          [ "ClientNode::Command (Opcode 4)", "page_native_protocol.html#autotoc_md202", null ],
          [ "ClientNode::AddPort (Opcode 5)", "page_native_protocol.html#autotoc_md203", null ],
          [ "ClientNode::RemovePort (Opcode 6)", "page_native_protocol.html#autotoc_md204", null ],
          [ "ClientNode::PortSetParam (Opcode 7)", "page_native_protocol.html#autotoc_md205", null ],
          [ "ClientNode::UseBuffers (Opcode 8)", "page_native_protocol.html#autotoc_md206", null ],
          [ "ClientNode::PortSetIO (Opcode 9)", "page_native_protocol.html#autotoc_md207", null ],
          [ "ClientNode::SetActivation (Opcode 10)", "page_native_protocol.html#autotoc_md208", null ],
          [ "ClientNode::PortSetMixInfo (Opcode 11)", "page_native_protocol.html#autotoc_md209", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Metadata", "page_native_protocol.html#autotoc_md210", [
        [ "Metadata methods", "page_native_protocol.html#autotoc_md211", [
          [ "Metadata::SetProperty (Opcode 1)", "page_native_protocol.html#autotoc_md212", null ],
          [ "Metadata::Clear (Opcode 2)", "page_native_protocol.html#autotoc_md213", null ]
        ] ],
        [ "Metadata events", "page_native_protocol.html#autotoc_md214", [
          [ "Metadata::Property (Opcode 0)", "page_native_protocol.html#autotoc_md215", null ]
        ] ]
      ] ],
      [ "PipeWire:Interface:Profiler", "page_native_protocol.html#autotoc_md216", [
        [ "Profiler methods", "page_native_protocol.html#autotoc_md217", null ],
        [ "Profiler events", "page_native_protocol.html#autotoc_md218", [
          [ "Profiler::Profile (Opcode 0)", "page_native_protocol.html#autotoc_md219", null ]
        ] ]
      ] ]
    ] ],
    [ "PipeWire Daemon", "page_daemon.html", [
      [ "Configuration Files", "page_daemon.html#autotoc_md42", [
        [ "Configuration File Format", "page_daemon.html#autotoc_md43", null ]
      ] ],
      [ "Logging", "page_daemon.html#autotoc_md44", null ]
    ] ],
    [ "PipeWire Tools", "page_tools.html", "page_tools" ],
    [ "PipeWire Session Manager", "page_session_manager.html", [
      [ "Client Management", "page_session_manager.html#autotoc_md65", null ],
      [ "Device Management", "page_session_manager.html#autotoc_md66", null ],
      [ "Endpoint Grouping", "page_session_manager.html#autotoc_md67", null ]
    ] ],
    [ "PulseAudio Compatibility", "page_pulseaudio.html", [
      [ "Internals - Mapping Between ALSA and Streams", "page_pulseaudio.html#autotoc_md281", [
        [ "ALSA Cards", "page_pulseaudio.html#autotoc_md282", null ],
        [ "Streams", "page_pulseaudio.html#autotoc_md283", null ]
      ] ],
      [ "Session Manager", "page_pulseaudio.html#autotoc_md284", [
        [ "ALSA UCM", "page_pulseaudio.html#autotoc_md285", null ],
        [ "ALSA Fallback", "page_pulseaudio.html#autotoc_md286", null ],
        [ "ALSA Pulse UCM", "page_pulseaudio.html#autotoc_md287", null ],
        [ "ALSA Pulse Fallback", "page_pulseaudio.html#autotoc_md288", null ]
      ] ],
      [ "PulseAudio", "page_pulseaudio.html#autotoc_md289", null ]
    ] ]
];